## package RefDB::CGI
## RefDB CGI support module

## markus@mhoenicka.de 2002-12-27
## $Id: CGI.pm,v 1.1 2002/12/29 23:06:44 mhoenicka Exp $

##   This program is free software; you can redistribute it and/or modify
##   it under the terms of the GNU General Public License as published by
##   the Free Software Foundation; either version 2 of the License, or
##   (at your option) any later version.
##   
##   This program is distributed in the hope that it will be useful,
##   but WITHOUT ANY WARRANTY; without even the implied warranty of
##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##   GNU General Public License for more details.
   
##   You should have received a copy of the GNU General Public License
##   along with this program; if not, write to the Free Software
##   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

## Package main documentation

=head1 NAME

RefDB::CGI - CGI support for RefDB Perl scripts

=head1 SYNOPSIS

  use RefDB::CGI;

  if (RefDB::CGI::is_cgi() == 1) {
      $template = RefDB::CGI::load_html("/usr/local/share/myapp/template.html");
  }



=head1 DESCRIPTION

Provides functions important to run RefDB scripts as CGI applications.

=head1 FEEDBACK

Send bug reports, questions, and comments to the refdb-users mailing list at:

refdb-users@lists.sourceforge.net

For list information and archives, please visit:

http://lists.sourceforge.net/lists/listinfo/refdb-users


=head1 AUTHOR

Markus Hoenicka, markus@mhoenicka.de

=head1 SEE ALSO

This module is part of the RefDB package, a reference manager and bibliography tool for markup languages. Please visit http://refdb.sourceforge.net for further information.

=cut

package RefDB::CGI;

## need this for logging
use RefDB::Log;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

( $VERSION ) = '$Revision: 1.1 $' =~ /\$Revision:\s+([^\s]+)/;

=head1 package functions

=head2 is_cgi

Title   : is_cgi

Usage   : $is_cgi = is_cgi();

Function: Checks whether app runs as a CGI app accepting POST data

Returns : 1 if CGI app, 0 if not

=cut

##********************************************************************
## is_cgi(): checks whether we run as CGI app
## Returns: 1 if CGI app, 0 if not
##********************************************************************
sub is_cgi() {
    my $request_method = $ENV{'REQUEST_METHOD'};
    my $content_length = $ENV{'CONTENT_LENGTH'};

    ## A web server will set the environment variable REQUEST_METHOD
    ## (among others) for CGI processes. If this envar is not set,
    ## we're not a CGI app
    if (defined($request_method)) {
	## we need POST data
	if ($request_method ne "POST") {
	    RefDB::Log::log_print("err", "Incorrect request method: $request_method");
	    print "Content-type: text/plain\n\nIncorrect request method: $request_method<<\n";
	    return 0;
	}
	elsif (!defined($content_length)) {
	    ## this is a web server error, should never happen
	    RefDB::Log::log_print("err", "Unknown request size");
	    print "Content-type: text/plain\n\nUnknown request size\n";
	    return 0;
	}
	return 1;
    }
    else {
	return 0; # no CGI
    }
} ## end of is_cgi

=head2 load_html

Title   : load_html

Usage   : $template = load_html("full/path/to/template.html")

Function: Reads a HTML template into a string

Returns : string if file was found, undef if not

=cut

##********************************************************************
## load_html(): reads html template into a string
## Arguments: path of template  file
## Return value is not used
##********************************************************************
sub load_html {
    my $frag = shift;
    my $fragstring;

    if (open FRAG, "<$frag") {
	while (<FRAG>) {
	    $fragstring = $fragstring . $_;
	}
    }
    else {
	RefDB::Log::log_print("err", "could not load html template $frag");
    }

    return $fragstring;

} ## end of load_html


1;
__END__

